==> spip_3.2.11.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_oc_lnc.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=oc_lnc
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// I
	'icone_evolution_visites' => 'Evolucion de las vesitas<br />@visites@ vesitas',
	'icone_repartition_actuelle' => 'Afichar la reparticion actuala',
	'icone_repartition_visites' => 'Reparticion de las vesitas',
	'icone_statistiques_visites' => 'Estadisticas',
	'info_affichier_visites_articles_plus_visites' => 'Afichar las vesitas pels <b>articles mai vesitats dempuèi lo començament:</b>',
	'info_comment_lire_tableau' => 'Cossí legir aquel tablèu',
	'info_forum_statistiques' => 'Estadisticas de las vesitas',
	'info_popularite_2' => 'popularitat del sit:',
	'info_popularite_3' => 'popularitat: @popularite@; vesitas: @visites@',
	'info_popularite_5' => 'popularitat:',
	'info_visites' => 'vesitas:',
	'info_visites_plus_populaires' => 'Afichar las vesitas <b>pels articles mai populars</b> e <b>pels darrièrs articles publicats:</b>',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Gerir las estadisticas', # MODIF

	// O
	'onglet_origine_visites' => 'Origina de las vesitas',
	'onglet_repartition_debut' => 'dempuèi la començança',
	'onglet_repartition_lang' => 'Reparticion per lengas',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_comment_lire_tableau' => 'Lo reng de l’article,
dins lo classament per popularitat, es indicat dins lo marge; la popularitat de l’article 
(una estimacion del nombre de vesitas quotidianas qu’el recebrà se lo ritme actual de consultacion se manten) e lo nombre de vesitas recebudas
dempuèi lo començament s’afichan dins la bofiga 
qu’apareis quora la mirga passa sul títol.',
	'texte_signification' => 'Las barras escuras representan las intradas cumuladas (total de las sosrubricas), las barras claras lo nombre de vesitas per cada rubrica.',
	'titre_evolution_visite' => 'Evolucion de las vesitas',
	'titre_liens_entrants' => 'Ligams intrants',
	'titre_page_statistiques' => 'Estadisticas per rubricas',
	'titre_page_statistiques_visites' => 'Estadisticas de las vesitas'
);

==> spip_4.4.5+dfsg.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_oc_lnc.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=oc_lnc
// ** ne pas modifier le fichier **

return [

	// I
	'icone_evolution_visites' => 'Evolucion de las vesitas<br />@visites@ vesitas',
	'icone_repartition_actuelle' => 'Afichar la reparticion actuala',
	'icone_repartition_visites' => 'Reparticion de las vesitas',
	'icone_statistiques_visites' => 'Estadisticas',
	'info_affichier_visites_articles_plus_visites' => 'Afichar las vesitas pels <b>articles mai vesitats dempuèi lo començament:</b>',
	'info_comment_lire_tableau' => 'Cossí legir aquel tablèu',
	'info_forum_statistiques' => 'Estadisticas de las vesitas',
	'info_popularite_2' => 'popularitat del sit:',
	'info_popularite_3' => 'popularitat: @popularite@; vesitas: @visites@',
	'info_popularite_5' => 'popularitat:',
	'info_visites' => 'vesitas:',
	'info_visites_plus_populaires' => 'Afichar las vesitas <b>pels articles mai populars</b> e <b>pels darrièrs articles publicats:</b>',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Gerir las estadisticas', # MODIF

	// O
	'onglet_origine_visites' => 'Origina de las vesitas',
	'onglet_repartition_debut' => 'dempuèi la començança',
	'onglet_repartition_lang' => 'Reparticion per lengas',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_comment_lire_tableau' => 'Lo reng de l’article,
dins lo classament per popularitat, es indicat dins lo marge; la popularitat de l’article 
(una estimacion del nombre de vesitas quotidianas qu’el recebrà se lo ritme actual de consultacion se manten) e lo nombre de vesitas recebudas
dempuèi lo començament s’afichan dins la bofiga 
qu’apareis quora la mirga passa sul títol.',
	'texte_signification' => 'Las barras escuras representan las intradas cumuladas (total de las sosrubricas), las barras claras lo nombre de vesitas per cada rubrica.',
	'titre_evolution_visite' => 'Evolucion de las vesitas',
	'titre_liens_entrants' => 'Ligams intrants',
	'titre_page_statistiques' => 'Estadisticas per rubricas',
	'titre_page_statistiques_visites' => 'Estadisticas de las vesitas',
];
